@@ -1,4 +1,4 @@
-import CIRS_063
+from cirs_063 import CIRS_063
 import constants as C
 from tqdm import tqdm
 import numpy as np
